package main

import (
	"fmt"
	"multisql/cfg"
	"multisql/mgr"
	"os"
)

func main() {
	params := cfg.GetParams()
	config, err := cfg.GetConfig(params)

	if err != nil {
		fmt.Fprintf(os.Stderr, "Błąd z konfiguracją: %v\n", err)
		os.Exit(1)
	}


	if params.OutDir == "" {
		params.OutDir = "."
	} else {
		fs, err := os.Stat(params.OutDir)
		if err != nil {
			fmt.Fprintf(os.Stderr, "Podany katalog wyników nie jest prawidłowy: %v\n", err)
			os.Exit(1)
		}
		if !fs.IsDir() {
			fmt.Fprintf(os.Stderr, "Ścieżka %s nie wskazuje na poprawny katalog\n", params.OutDir)
		}
	}

	manager, err := mgr.Create(params.Verbose, params.OutDir, config)
	if err != nil {
		fmt.Fprintf(os.Stderr, "Nie można wystartować operacji: %v\n", err)
		os.Exit(1)
	}

	err = manager.Run()

	if err != nil {
		fmt.Fprintf(os.Stderr, "Błąd przetwarzania: %v\n", err)
		os.Exit(1)
	}

}
